<?php
$width = 16;
if (isset($_REQUEST['w'])) {
    $width = (int)($_REQUEST['w'] ?? 32);
    if($width < 1) {
        $width = 1;
    }
}
$screenWidth = 800;
$screenHeight = 600;
?>
<!DOCTYPE html>
<html>
 <head>
  <meta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1.0, maximum-scale=1.0">

  <title>Game World</title>

  <style type="text/css">
    BODY {
        background:#333;
        text-align:center;
        margin: 0;
        padding:  0;
    }

    section {
        width: 100%;
        min-height: 100vh;
        background: black;
        display: grid;
    
        canvas {
            border: 3px solid #444;
            box-shadow:1px 1px 4px #333;
            border-radius:1rem;
            place-self: center;
            width:800px;
            height:600px;
        }  
    }
  </style>

</head>
<body>

<section id="mainContent">
    <canvas id="mainCanvas" width="<?php echo $screenWidth; ?>" height="<?php echo $screenHeight; ?>"></canvas>
</section>

<script src="./map.js"></script>
<script src="./js/tiles.js"></script>
<script src="./js/events.js"></script>
<script type="text/javascript">

var blockWidth = <?php echo $width; ?>;
var screenWidth = <?php echo $screenWidth; ?>;
var screenHeight = <?php echo $screenHeight; ?>;
var main_canvas;
var ctx;
var game;
var tiles;

var isDragging = false;
var dragStartX = 0;
var dragStartY = 0;
var WorldCoord = { x:0, y:0 }

var visibleWidthTiles = parseInt(screenWidth /  blockWidth);
var visibleHeightTiles = parseInt(screenHeight /  blockWidth);

var tilemap;
var numBlocksWidth;
var numBlocksHeight;
var tileWidth;
var tileHeight;
var layers;


function init() {
    var main_canvas = document.getElementById("mainCanvas");
    ctx = main_canvas.getContext("2d");

    tiles = new Tiles(ctx, "./newWorld.png", 32);
    tiles.draw(tilesList);
    tiles.updateCoordinatesDisplay();

    main_canvas.addEventListener('click', function(event) {
        var rect = main_canvas.getBoundingClientRect();
        var mouseX = event.clientX - rect.left;
        var mouseY = event.clientY - rect.top;

        // Calculate tile coordinates
        var tileX = Math.floor((mouseX + WorldCoord.x * blockWidth) / blockWidth);
        var tileY = Math.floor((mouseY + WorldCoord.y * blockWidth) / blockWidth);

        console.log("Clicked on tile at coordinates:", tileX, tileY);
    });
}

window.onload = function () {

    fetch('./newWorld.json')
    .then(response => response.json())
    .then(data => {
        // Parse the JSON data
        tilemap = data;

        // Access tilemap data
        numBlocksWidth = tilemap.width;
        numBlocksHeight = tilemap.height;
        tileWidth = tilemap.tilewidth;
        tileHeight = tilemap.tileheight;
        layers = tilemap.layers;

        init();

        mainCanvas.addEventListener('mousedown', (event) => tiles.handleMouseDown(event));
        mainCanvas.addEventListener('mousemove', (event) => tiles.handleMouseMove(event));
        mainCanvas.addEventListener('mouseup', () => tiles.handleMouseUp());
  })
  .catch(error => console.error('Error loading tilemap:', error));
};

</script>

</body>
</html>